==> snortsms-0.14.9.tbz: www/snortsms/policies/dsp_select.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

$totalrows = $rsRules->numRows();

/*** Get start and end rows ***/
$startrow = $_REQUEST['sr'];
if ($startrow <= 0)
	{ $startrow = 0; }
$endrow = $startrow + $GBL['maxrows'] - 1;
if ($endrow > $totalrows)
	{ $endrow = $totalrows-1; }


/*** Get pages ***/
$totalpages = round($totalrows / $GBL['maxrows'] + .5);
$curpage = $startrow / $GBL['maxrows'];

$startpage = $curpage - round($GBL['maxpages']/2);
if ($startpage <= 0)
	{ $startpage = 0; }

$endpage = $curpage + round($GBL['maxpages']/2);
if ($endpage >= $totalpages)
	{ $endpage = $totalpages; }

	
	
	
/* Draw profile combo box  */
$temp_policyid = $_REQUEST['FRM_policyid'];
$temp_cat = $_REQUEST['FRM_cat'];

$i = 0;
$temp_policy = "<SELECT name=\"FRM_policyid\" onchange=\"this.form.submit();\">";
while ($row = $rsPols->fetchRow(DB_FETCHMODE_ASSOC,$i++))
	{
	$selected = ($row['id'] == $temp_policyid ? "selected" : "" );
	$temp_policy .= "<OPTION value=\"".$row['id']."\" $selected>".$row['name']."</OPTION>";
	
	}
$temp_policy .= "</SELECT>";
	
	

include_once("../lib/func_DrawRepHeader.php");

DrawRepHeader("Rule Profiles");
?>

<script language="JavaScript" type="text/javascript">
<!-- 
function CheckAllINBOX()
	{
	for (var i = 0; i < document.CheckForm.elements.length; i++)
		{
		if(document.CheckForm.elements[i].type == 'checkbox')
			{
			document.CheckForm.elements[i].checked = !(document.CheckForm.elements[i].checked);
			}
		}
	}
//-->
</script>

<div align="center">



<?
include("dsp_pagenate.php");
?>



<table border="0" class="bg1" cellspacing="1" cellpadding="0" width="600">
<tr><td>













<table border="0" width="700" class="bg4" cellspacing="0" cellpadding="2">
<tr class="combo1">
<th colspan="6">Assigned Rules - <?=$temp_cat?></Th>
</tr>
<tr class="bg2">
<td class="label" colspan="5">
<FORM action="index.php" method="GET">
<input type="hidden" name="fuseaction" value="policies.<?=$Fusebox['fuseaction']?>">
<input type="hidden" name="FRM_cat" value="<?=$temp_cat?>">
Rule Profile : <?=$temp_policy?>
</FORM>
<BR>
<FORM name="CheckForm" action="index.php?fuseaction=policies.action" method="POST">
<INPUT type="hidden" name="FRM_query" value="<?=$temp_query?>">
<INPUT type="hidden" name="FRM_policyid" value="<?=$temp_policyid?>">
</td>
<td align="right">
<a href="index.php?fuseaction=policies.catagories&FRM_policyid=<?=$temp_policyid?>" title="Back to rule categories">[ &lt;&lt; back ]</a>
</td>
</tr>
<tr class="bg2">
<td>&nbsp;</td>
<td class="label">Pick</td>
<td class="label">SID</td>
<td class="label">Catagory</td>
<td class="label" width="100">Name</td>
<td class="label">Rule Definition</td>
</tr>
<?
$temp_back = "bg2";
for($rownum = $startrow ; $rownum <= $endrow ; $rownum++)
	{
	$row = $rsRules->fetchRow(DB_FETCHMODE_ASSOC,$rownum);
	$temp_back = ( $temp_back == "bg2" ? "bg4" : "bg2");
	
	if ( $row['ruleid'] == NULL )
		{
		$temp_selected = "<a href=\"index.php?fuseaction=policies.activaterule&FRM_sid=".$row['sid']."&FRM_policyid=".$temp_policyid."\" title=\"Activate Rule\"><img src=\"images/check-0.png\" border=\"0\"></a>";
		}
	else
		{
		$temp_selected = "<a href=\"index.php?fuseaction=policies.deactivaterule&FRM_sid=".$row['sid']."&FRM_policyid=".$temp_policyid."\" title=\"Deactivate Rule\"><img src=\"images/check-1.png\" border=\"0\"></a>";
		}
	$ruledef = htmlspecialchars($row['rule']);
	$ruledef = wordwrap($ruledef, 60, "<br>",1);
	?>
	<tr class="<?=$temp_back?>" valign="top">
	<td nowrap><input type=checkbox name="FRM_row[]" value="<?=$row['sid']?>"></td>
	<td><?=$temp_selected?> &nbsp;</td>
	<td><?=$row['sid']?></td>
	<td nowrap align="center"><?=$row['cata']?></td>
	<td width="100"><?=htmlspecialchars($row['name'])?></td>
	<td><?=$ruledef?></td>	
	</tr>
	<?	
	}
?>

</table>





</td>
</tr>
<tr>
<td>



<TABLE border="0" width="700" class="bg2">
<tr>
<td>
<a href="javascript:void(0)" onClick="CheckAllINBOX();">[Toggle All]</a>
<B>Action:</B>
<SELECT name="FRM_action">
<OPTION>-Choose Action-</OPTION>
<OPTION value="Activate">Activate</OPTION>
<OPTION value="Deactivate">Deactivate</OPTION>
</SELECT>
<INPUT type="submit" value="Submit"> 
<a href="index.php?fuseaction=rules.main">[Add/Edit Rules]</a>
</td>

<td align="right">
<a href="index.php?fuseaction=policies.action&FRM_action=A&FRM_policyid=<?=$temp_policyid?>&FRM_cat=<?=$temp_cat?>">[Activate All]</a> &nbsp; 
<a href="index.php?fuseaction=policies.action&FRM_action=D&FRM_policyid=<?=$temp_policyid?>&FRM_cat=<?=$temp_cat?>">[Deactivate All]</a>
</td>
</tr>
</table>






</td>
</tr>
</table>



<?
include("dsp_pagenate.php");
?>



</FORM>

==> snortsms-1.0.0.tbz: www/snortsms/policies/dsp_select.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

$totalrows = $rsRules->numRows();

/*** Get start and end rows ***/
$startrow = $_REQUEST['sr'];
if ($startrow <= 0)
	{ $startrow = 0; }
$endrow = $startrow + $GBL['maxrows'] - 1;
if ($endrow > $totalrows)
	{ $endrow = $totalrows-1; }


/*** Get pages ***/
$totalpages = round($totalrows / $GBL['maxrows'] + .5);
$curpage = $startrow / $GBL['maxrows'];

$startpage = $curpage - round($GBL['maxpages']/2);
if ($startpage <= 0)
	{ $startpage = 0; }

$endpage = $curpage + round($GBL['maxpages']/2);
if ($endpage >= $totalpages)
	{ $endpage = $totalpages; }

	
	
	
/* Draw profile combo box  */
$temp_policyid = $_REQUEST['FRM_policyid'];
$temp_cat = $_REQUEST['FRM_cat'];

$i = 0;
$temp_policy = "<SELECT name=\"FRM_policyid\" onchange=\"this.form.submit();\">";
while ($row = $rsPols->fetchRow(DB_FETCHMODE_ASSOC,$i++))
	{
	$selected = ($row['id'] == $temp_policyid ? "selected" : "" );
	$temp_policy .= "<OPTION value=\"".$row['id']."\" $selected>".$row['name']."</OPTION>";
	
	}
$temp_policy .= "</SELECT>";
	
	

include_once("../lib/func_DrawRepHeader.php");

DrawRepHeader("Rule Profiles");
?>

<script language="JavaScript" type="text/javascript">
<!-- 
function CheckAllINBOX()
	{
	for (var i = 0; i < document.CheckForm.elements.length; i++)
		{
		if(document.CheckForm.elements[i].type == 'checkbox')
			{
			document.CheckForm.elements[i].checked = !(document.CheckForm.elements[i].checked);
			}
		}
	}
//-->
</script>

<div align="center">



<?
include("dsp_pagenate.php");
?>



<table border="0" class="bg1" cellspacing="1" cellpadding="0" width="600">
<tr><td>













<table border="0" width="800" class="bg4" cellspacing="0" cellpadding="2">
<tr class="combo1">
<th colspan="6">Assigned Rules - <?=$temp_cat?></Th>
</tr>
<tr class="bg2">
<td class="label" colspan="5">
<FORM action="index.php" method="GET">
<input type="hidden" name="fuseaction" value="policies.<?=$Fusebox['fuseaction']?>">
<input type="hidden" name="FRM_cat" value="<?=$temp_cat?>">
Rule Profile : <?=$temp_policy?>
</FORM>
<BR>
<FORM name="CheckForm" action="index.php?fuseaction=policies.action" method="POST">
<INPUT type="hidden" name="FRM_query" value="<?=$temp_query?>">
<INPUT type="hidden" name="FRM_policyid" value="<?=$temp_policyid?>">
</td>
<td align="right">
<a href="index.php?fuseaction=policies.catagories&FRM_policyid=<?=$temp_policyid?>" title="Back to rule categories">[ &lt;&lt; back ]</a>
</td>
</tr>
<tr class="bg2">
<td>&nbsp;</td>
<td class="label">Pick</td>
<td class="label">SID</td>
<td class="label">Catagory</td>
<td class="label">Name</td>
<td class="label">Rule Definition</td>
</tr>
<?
$temp_back = "bg2";
for($rownum = $startrow ; $rownum <= $endrow ; $rownum++)
	{
	$row = $rsRules->fetchRow(DB_FETCHMODE_ASSOC,$rownum);
	$temp_back = ( $temp_back == "bg2" ? "bg4" : "bg2");
	
	if ( $row['ruleid'] == NULL )
		{
		$temp_selected = "<a href=\"index.php?fuseaction=policies.activaterule&FRM_sid=".$row['sid']."&FRM_policyid=".$temp_policyid."\" title=\"Activate Rule\"><img src=\"images/check-0.png\" border=\"0\"></a>";
		}
	else
		{
		$temp_selected = "<a href=\"index.php?fuseaction=policies.deactivaterule&FRM_sid=".$row['sid']."&FRM_policyid=".$temp_policyid."\" title=\"Deactivate Rule\"><img src=\"images/check-1.png\" border=\"0\"></a>";
		}
	$ruledef = htmlspecialchars($row['rule']);
	$ruledef = wordwrap($ruledef, 60, "<br>",1);
	?>
	<tr class="<?=$temp_back?>" valign="top">
	<td nowrap><input type=checkbox name="FRM_row[]" value="<?=$row['sid']?>"></td>
	<td><?=$temp_selected?> &nbsp;</td>
	<td><?=$row['sid']?></td>
	<td nowrap align="center"><?=$row['cata']?></td>
	<td ><a href="index.php?fuseaction=rules.view&FRM_sid=<?=$row['sid']?>&FRM_cat=<?=$row['cata']?>"><?=htmlspecialchars($row['name'])?></td>
	<td><?=$ruledef?></td>	
	</tr>
	<?	
	}
?>

</table>





</td>
</tr>
<tr>
<td>



<TABLE border="0" width="700" class="bg2">
<tr>
<td>
<a href="javascript:void(0)" onClick="CheckAllINBOX();">[Toggle All]</a>
<B>Action:</B>
<SELECT name="FRM_action">
<OPTION>-Choose Action-</OPTION>
<OPTION value="Activate">Activate</OPTION>
<OPTION value="Deactivate">Deactivate</OPTION>
</SELECT>
<INPUT type="submit" value="Submit"> 
<a href="index.php?fuseaction=rules.main">[Add/Edit Rules]</a>
</td>

<td align="right">
<a href="index.php?fuseaction=policies.action&FRM_action=A&FRM_policyid=<?=$temp_policyid?>&FRM_cat=<?=$temp_cat?>">[Activate All]</a> &nbsp; 
<a href="index.php?fuseaction=policies.action&FRM_action=D&FRM_policyid=<?=$temp_policyid?>&FRM_cat=<?=$temp_cat?>">[Deactivate All]</a>
</td>
</tr>
</table>






</td>
</tr>
</table>



<?
include("dsp_pagenate.php");
?>



</FORM>
